@@ -50,11 +50,11 @@ parameters, and site parameters
 
 =head1 VERSION
 
-Version 0.204
+Version 0.205
 
 =cut
 
-our $VERSION = '0.204';
+our $VERSION = '0.205';
 
 
 
@@ -160,6 +160,45 @@ sub DESTROY {
 }
 
 
+=head2 exists
+
+Determine parameter existence.
+
+=cut
+
+sub exists {
+    my ( $self, $param ) = @_;
+    my $type = $self->{'CELL_CONFTYPE'};
+
+    my $bool;
+    if ( $type eq 'meta' ) {
+        $bool = exists $meta->{ $param };
+    } elsif ( $type eq 'core' ) {
+        $bool = exists $core->{ $param };
+    } elsif ( $type eq 'site' ) {
+        $bool = exists $site->{ $param };
+        if ( ! $bool ) {
+            $bool = exists $core->{ $param };
+        }
+    } else {
+        die "AAAAAAAAAAGGAHHAGHHG! improper param type in exists routine";
+    }
+    return $bool;
+}
+
+
+=head2 get
+
+Wrapper for get_param
+
+=cut
+
+sub get {
+    my ( $self, $param ) = @_;
+    return $self->get_param( $param );
+}
+
+
 =head2 get_param
 
 Get value of config param provided in the argument.
